#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from __future__ import print_function
from openeye import oechem

mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "C\C(C)=C(\C)C.O\C(C)=C(\C)O.O\C(C)=C(\O)C.CC(O)=C(O)C")

for bond in mol.GetBonds():
    if bond.GetOrder() == 2:
        cip = oechem.OEPerceiveCIPStereo(mol, bond)
        print("bond %d is" % bond.GetIdx(), end=" ")
        if bond.HasStereoSpecified():
            if cip == oechem.OECIPBondStereo_E:
                print('E')
            if cip == oechem.OECIPBondStereo_Z:
                print('Z')
            if cip == oechem.OECIPBondStereo_NotStereo:
                print('not a CIP stereo center')
        if cip == oechem.OECIPBondStereo_UnspecStereo:
            print('a CIP stereo center without specified stereochemistry')
# @ </SNIPPET>
